MockGitHubApi

Struct MockGitHubApi 

pub struct MockGitHubApi { /* private fields */ }
The GitHub operations this crate exposes — the interface consumers code against and mock in tests.

Implementations

Source

impl MockGitHubApi

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl MockGitHubApi

pub fn expect_run(&mut self) -> &mut Expectation

Create an Expectation for mocking the run method

pub fn expect_run_raw(&mut self) -> &mut Expectation

Create an Expectation for mocking the run_raw method

pub fn expect_version(&mut self) -> &mut Expectation

Create an Expectation for mocking the version method

pub fn expect_capabilities(&mut self) -> &mut Expectation

Create an Expectation for mocking the capabilities method

pub fn expect_auth_status(&mut self) -> &mut Expectation

Create an Expectation for mocking the auth_status method

pub fn expect_auth_status_for(&mut self) -> &mut Expectation

Create an Expectation for mocking the auth_status_for method

pub fn expect_repo_view(&mut self) -> &mut Expectation

Create an Expectation for mocking the repo_view method

pub fn expect_pr_list(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_list method

pub fn expect_pr_list_with(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_list_with method

pub fn expect_pr_list_for_source_branch(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_list_for_source_branch method

pub fn expect_pr_list_for_branch(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_list_for_branch method

pub fn expect_pr_view(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_view method

pub fn expect_issue_list(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_list method

pub fn expect_issue_list_with(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_list_with method

pub fn expect_pr_create(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_create method

pub fn expect_api(&mut self) -> &mut Expectation

Create an Expectation for mocking the api method

pub fn expect_pr_merge(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_merge method

pub fn expect_pr_mark_ready(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_mark_ready method

pub fn expect_pr_close(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_close method

pub fn expect_pr_add_labels(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_add_labels method

pub fn expect_pr_remove_labels(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_remove_labels method

pub fn expect_pr_checkout(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_checkout method

pub fn expect_pr_checks(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_checks method

pub fn expect_pr_review(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_review method

pub fn expect_pr_comment(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_comment method

pub fn expect_pr_edit(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_edit method

pub fn expect_pr_feedback(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_feedback method

pub fn expect_pr_diff(&mut self) -> &mut Expectation

Create an Expectation for mocking the pr_diff method

pub fn expect_workflow_list(&mut self) -> &mut Expectation

Create an Expectation for mocking the workflow_list method

pub fn expect_workflow_list_with(&mut self) -> &mut Expectation

Create an Expectation for mocking the workflow_list_with method

pub fn expect_workflow_view(&mut self) -> &mut Expectation

Create an Expectation for mocking the workflow_view method

pub fn expect_run_list(&mut self) -> &mut Expectation

Create an Expectation for mocking the run_list method

pub fn expect_run_view(&mut self) -> &mut Expectation

Create an Expectation for mocking the run_view method

pub fn expect_run_watch(&mut self) -> &mut Expectation

Create an Expectation for mocking the run_watch method

pub fn expect_workflow_dispatch(&mut self) -> &mut Expectation

Create an Expectation for mocking the workflow_dispatch method

pub fn expect_run_rerun(&mut self) -> &mut Expectation

Create an Expectation for mocking the run_rerun method

pub fn expect_run_cancel(&mut self) -> &mut Expectation

Create an Expectation for mocking the run_cancel method

pub fn expect_issue_create(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_create method

pub fn expect_issue_create_with(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_create_with method

pub fn expect_issue_add_labels(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_add_labels method

pub fn expect_issue_remove_labels(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_remove_labels method

pub fn expect_issue_view(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_view method

pub fn expect_issue_close(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_close method

pub fn expect_issue_reopen(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_reopen method

pub fn expect_issue_comment(&mut self) -> &mut Expectation

Create an Expectation for mocking the issue_comment method

pub fn expect_release_list(&mut self) -> &mut Expectation

Create an Expectation for mocking the release_list method

pub fn expect_release_view(&mut self) -> &mut Expectation

Create an Expectation for mocking the release_view method

pub fn expect_release_create(&mut self) -> &mut Expectation

Create an Expectation for mocking the release_create method

pub fn expect_release_delete(&mut self) -> &mut Expectation

Create an Expectation for mocking the release_delete method