pub struct MockGitHubApi { /* private fields */ }Expand description
The GitHub operations this crate exposes — the interface consumers code against and mock in tests.
Implementations
Sourceimpl MockGitHubApi
impl MockGitHubApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockGitHubApi
impl MockGitHubApi
Sourcepub fn expect_run(&mut self) -> &mut Expectation
pub fn expect_run(&mut self) -> &mut Expectation
Create an Expectation for mocking the run method
Sourcepub fn expect_run_raw(&mut self) -> &mut Expectation
pub fn expect_run_raw(&mut self) -> &mut Expectation
Create an Expectation for mocking the run_raw method
Sourcepub fn expect_version(&mut self) -> &mut Expectation
pub fn expect_version(&mut self) -> &mut Expectation
Create an Expectation for mocking the version method
Sourcepub fn expect_auth_status(&mut self) -> &mut Expectation
pub fn expect_auth_status(&mut self) -> &mut Expectation
Create an Expectation for mocking the auth_status method
Sourcepub fn expect_repo_view(&mut self) -> &mut Expectation
pub fn expect_repo_view(&mut self) -> &mut Expectation
Create an Expectation for mocking the repo_view method
Sourcepub fn expect_pr_list(&mut self) -> &mut Expectation
pub fn expect_pr_list(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_list method
Sourcepub fn expect_pr_list_for_branch(&mut self) -> &mut Expectation
pub fn expect_pr_list_for_branch(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_list_for_branch method
Sourcepub fn expect_pr_view(&mut self) -> &mut Expectation
pub fn expect_pr_view(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_view method
Sourcepub fn expect_issue_list(&mut self) -> &mut Expectation
pub fn expect_issue_list(&mut self) -> &mut Expectation
Create an Expectation for mocking the issue_list method
Sourcepub fn expect_pr_create(&mut self) -> &mut Expectation
pub fn expect_pr_create(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_create method
Sourcepub fn expect_api(&mut self) -> &mut Expectation
pub fn expect_api(&mut self) -> &mut Expectation
Create an Expectation for mocking the api method
Sourcepub fn expect_pr_merge(&mut self) -> &mut Expectation
pub fn expect_pr_merge(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_merge method
Sourcepub fn expect_pr_ready(&mut self) -> &mut Expectation
pub fn expect_pr_ready(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_ready method
Sourcepub fn expect_pr_close(&mut self) -> &mut Expectation
pub fn expect_pr_close(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_close method
Sourcepub fn expect_pr_checks(&mut self) -> &mut Expectation
pub fn expect_pr_checks(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_checks method
Sourcepub fn expect_pr_review(&mut self) -> &mut Expectation
pub fn expect_pr_review(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_review method
Sourcepub fn expect_pr_comment(&mut self) -> &mut Expectation
pub fn expect_pr_comment(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_comment method
Sourcepub fn expect_pr_feedback(&mut self) -> &mut Expectation
pub fn expect_pr_feedback(&mut self) -> &mut Expectation
Create an Expectation for mocking the pr_feedback method
Sourcepub fn expect_run_list(&mut self) -> &mut Expectation
pub fn expect_run_list(&mut self) -> &mut Expectation
Create an Expectation for mocking the run_list method
Sourcepub fn expect_run_view(&mut self) -> &mut Expectation
pub fn expect_run_view(&mut self) -> &mut Expectation
Create an Expectation for mocking the run_view method
Sourcepub fn expect_run_watch(&mut self) -> &mut Expectation
pub fn expect_run_watch(&mut self) -> &mut Expectation
Create an Expectation for mocking the run_watch method
Sourcepub fn expect_issue_create(&mut self) -> &mut Expectation
pub fn expect_issue_create(&mut self) -> &mut Expectation
Create an Expectation for mocking the issue_create method
Sourcepub fn expect_issue_view(&mut self) -> &mut Expectation
pub fn expect_issue_view(&mut self) -> &mut Expectation
Create an Expectation for mocking the issue_view method
Sourcepub fn expect_release_list(&mut self) -> &mut Expectation
pub fn expect_release_list(&mut self) -> &mut Expectation
Create an Expectation for mocking the release_list method
Sourcepub fn expect_release_view(&mut self) -> &mut Expectation
pub fn expect_release_view(&mut self) -> &mut Expectation
Create an Expectation for mocking the release_view method